@@ -14,6 +14,8 @@
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
+#include <Akonadi/TagCache>
+
 #include <KContacts/VCardDrag>
 
 #include <KCalUtils/ICalDrag>
@@ -831,7 +833,15 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
     const bool roundTop = !prevMultiItem();
     const bool roundBottom = !nextMultiItem();
 
-    drawRoundedRect(&p, QRect(fmargin, fmargin, width() - fmargin * 2, height() - fmargin * 2), mSelected, bgColor, frameColor, true, ft, roundTop, roundBottom);
+    drawRoundedRect(&p,
+                    QRect(fmargin, fmargin, width() - fmargin * 2, height() - fmargin * 2),
+                    mSelected,
+                    bgColor,
+                    frameColor,
+                    true,
+                    ft,
+                    roundTop,
+                    roundBottom);
 
     // calculate the height of the full version (case 4) to test whether it is
     // possible
@@ -1038,7 +1048,15 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
     }
 }
 
-void AgendaItem::drawRoundedRect(QPainter *p, QRect rect, bool selected, const QColor &bgColor, const QColor &frameColor, bool frame, int ft, bool roundTop, bool roundBottom)
+void AgendaItem::drawRoundedRect(QPainter *p,
+                                 QRect rect,
+                                 bool selected,
+                                 const QColor &bgColor,
+                                 const QColor &frameColor,
+                                 bool frame,
+                                 int ft,
+                                 bool roundTop,
+                                 bool roundBottom)
 {
     Q_UNUSED(ft)
     if (!mValid) {
@@ -1111,14 +1129,14 @@ void AgendaItem::drawRoundedRect(QPainter *p, QRect rect, bool selected, const Q
 QColor AgendaItem::getCategoryColor() const
 {
     const QStringList &categories = mIncidence->categories();
-    if (categories.isEmpty() || !CalendarSupport::KCalPrefs::instance()->hasCategoryColor(categories.first())) {
+    if (categories.isEmpty() || !Akonadi::TagCache::instance()->tagColor(categories.first()).isValid()) {
         const auto colorPreference = mEventView->preferences()->agendaViewColors();
         if (colorPreference == PrefsBase::CategoryOnly || !mResourceColor.isValid()) {
             return CalendarSupport::KCalPrefs::instance()->unsetCategoryColor();
         }
         return mResourceColor;
     }
-    return CalendarSupport::KCalPrefs::instance()->categoryColor(categories.first());
+    return Akonadi::TagCache::instance()->tagColor(categories.first());
 }
 
 QColor AgendaItem::getFrameColor(const QColor &resourceColor, const QColor &categoryColor) const
